@@ -5,7 +5,7 @@ checkfunc() {
 	mstart "Checking for $2"
 	if not hinted $1 'found' 'missing'; then
 		try_start
-    try_add '#define _GNU_SOURCE'
+		try_add '#define _GNU_SOURCE'
 		funcincludes "$3" "$4" "$includes"
 		try_add "int main(void) { $2($3); return 0; }"
 		try_link -O0 -fno-builtin
@@ -14,12 +14,24 @@ checkfunc() {
 }
 
 funcincludes() {
+	r="x"
+
+	case "$2 $3" in
+		*stdlib.h*) r="s$r" ;;
+	esac
+
 	case "$1" in
-		*NULL*) try_includes "stdlib.h" ;;
+		*NULL*) r="n$r" ;;
+	esac
+
+	case "$r" in
+		*nx) try_includes "stdlib.h" ;;
 	esac
 
 	test -n "$3" && try_includes $3
 	test -n "$2" && try_includes $2
+
+	unset r
 }
 
 # The naming scheme looks regular but it isn't!
@@ -31,7 +43,7 @@ checkfunc d_access 'access' "NULL,0" 'unistd.h'
 checkfunc d_accessx 'accessx'
 checkfunc d_aintl 'aintl'
 checkfunc d_alarm 'alarm' "0" 'unistd.h'
-checkfunc d_asctime64 'asctime64'
+checkfunc d_asctime64 'asctime64' "NULL" 'time.h'
 checkfunc d_atolf 'atolf'
 checkfunc d_atoll 'atoll'
 checkfunc d_backtrace 'backtrace' 'NULL, 0' 'execinfo.h'
@@ -44,12 +56,12 @@ checkfunc d_chsize 'chsize' "0,0"
 checkfunc d_class 'class'
 checkfunc d_clearenv 'clearenv' "" 'stdlib.h'
 checkfunc d_closedir 'closedir' "NULL" 'dirent.h sys/types.h'
-checkfunc d_crypt 'crypt' "NULL,NULL" 'crypt.h'
-checkfunc d_ctermid 'ctermid'
+checkfunc d_crypt 'crypt' "NULL,NULL" 'crypt.h unistd.h'
+checkfunc d_ctermid 'ctermid' "NULL" 'stdio.h'
 checkfunc d_ctime64 'ctime64'
-checkfunc d_cuserid 'cuserid'
+checkfunc d_cuserid 'cuserid' "NULL" 'stdio.h'
 checkfunc d_difftime 'difftime' "0,0" 'time.h'
-checkfunc d_difftime64 'difftime64'
+checkfunc d_difftime64 'difftime64' "0,0" 'time.h'
 checkfunc d_dirfd 'dirfd' "NULL" 'dirent.h sys/types.h'
 checkfunc d_dladdr 'dladdr' 'NULL, NULL' 'dlfcn.h'
 checkfunc d_dlerror 'dlerror' "" 'dlfcn.h'
@@ -70,7 +82,8 @@ checkfunc d_fchmod 'fchmod' "0,0" 'unistd.h sys/stat.h'
 checkfunc d_fchmodat 'fchmodat' "0,NULL,0,0" 'unistd.h sys/stat.h'
 checkfunc d_fchown 'fchown' "0,0,0" 'unistd.h'
 checkfunc d_fcntl 'fcntl' "0,0" 'unistd.h fcntl.h'
-checkfunc d_fdclose 'fdclose'
+checkfunc d_fdopendir 'fdopendir' "0" 'dirent.h sys/types.h'
+checkfunc d_fdclose 'fdclose' "NULL,NULL" 'stdio.h'
 checkfunc d_ffs 'ffs' "0" 'strings.h'
 checkfunc d_ffsl 'ffsl' "0" 'strings.h'
 checkfunc d_fgetpos 'fgetpos' "NULL, 0" 'stdio.h'
@@ -91,7 +104,7 @@ checkfunc d_getaddrinfo 'getaddrinfo' "NULL,NULL,NULL,NULL" 'sys/types.h sys/soc
 checkfunc d_get_current_dir_name 'get_current_dir_name' "" 'unistd.h'
 checkfunc d_getcwd 'getcwd' 'NULL,0' 'unistd.h'
 checkfunc d_getespwnam 'getespwnam'
-checkfunc d_getfsstat 'getfsstat'
+checkfunc d_getfsstat 'getfsstat' "NULL,0,0" 'sys/types.h sys/mount.h'
 checkfunc d_getgrent 'getgrent' "" 'sys/types.h grp.h'
 checkfunc d_getgrps 'getgroups' "0,NULL" 'unistd.h'
 checkfunc d_gethbyaddr 'gethostbyaddr' "NULL,0,0" 'netdb.h'
@@ -102,7 +115,7 @@ checkfunc d_gethent 'gethostent' "" 'netdb.h'
 checkfunc d_gethname 'gethostname' "NULL,0" 'unistd.h'
 checkfunc d_getitimer 'getitimer' "0,NULL" 'sys/time.h'
 checkfunc d_getlogin 'getlogin' "" 'unistd.h'
-checkfunc d_getmnt 'getmnt'
+checkfunc d_getmnt 'getmnt' "NULL,NULL,0,0,NULL" 'sys/types.h sys/param.h sys/mount.h'
 checkfunc d_getmntent 'getmntent' "NULL" 'stdio.h mntent.h'
 checkfunc d_getnameinfo 'getnameinfo' "NULL,0,NULL,0,NULL,0,0" 'sys/socket.h netdb.h'
 checkfunc d_getnent 'getnetent' "" 'netdb.h'
@@ -128,7 +141,7 @@ checkfunc d_setsent 'setservent' "0" 'netdb.h'
 checkfunc d_endsent 'endservent' "" 'netdb.h'
 checkfunc d_getspnam 'getspnam' "NULL" 'shadow.h'
 checkfunc d_gettimeod 'gettimeofday' 'NULL,NULL' 'sys/time.h'
-checkfunc d_gmtime64 'gmtime64'
+checkfunc d_gmtime64 'gmtime64' "NULL" 'time.h'
 checkfunc d_hasmntopt 'hasmntopt' "NULL,NULL" 'stdio.h mntent.h'
 checkfunc d_htonl 'htonl' "0" 'stdio.h sys/types.h netinet/in.h arpa/inet.h'
 checkfunc d_ilogbl 'ilogbl' "0.0" 'math.h'
@@ -142,7 +155,7 @@ checkfunc d_killpg 'killpg' "0,0" 'signal.h'
 checkfunc d_lchown 'lchown' "NULL, 0, 0" 'unistd.h'
 checkfunc d_link 'link' 'NULL,NULL' 'unistd.h'
 checkfunc d_linkat 'linkat' '0,NULL,0,NULL,0' 'unistd.h'
-checkfunc d_localtime64 'localtime64'
+checkfunc d_localtime64 'localtime64' "NULL" 'time.h'
 checkfunc d_localeconv_l 'localeconv_l' 'NULL' 'locale.h'
 checkfunc d_locconv 'localeconv' "" 'locale.h'
 checkfunc d_lockf 'lockf' "0,0,0" 'unistd.h'
@@ -163,13 +176,13 @@ checkfunc d_memmove 'memmove' "NULL, NULL, 0" 'string.h'
 checkfunc d_memrchr 'memrchr' "NULL, 0, 0" 'string.h'
 checkfunc d_memset 'memset' "NULL, 0, 0" 'string.h'
 checkfunc d_mkdir 'mkdir' 'NULL, 0' 'sys/stat.h'
-checkfunc d_mkdtemp 'mkdtemp' 'NULL'
+checkfunc d_mkdtemp 'mkdtemp' 'NULL' 'stdlib.h'
 checkfunc d_mkfifo 'mkfifo' 'NULL,0' 'sys/types.h sys/stat.h'
 checkfunc d_mkostemp 'mkostemp' 'NULL,0' 'stdlib.h'
-checkfunc d_mkstemp 'mkstemp' 'NULL'
-checkfunc d_mkstemps 'mkstemps' 'NULL,0'
+checkfunc d_mkstemp 'mkstemp' 'NULL' 'stdlib.h'
+checkfunc d_mkstemps 'mkstemps' 'NULL,0' 'stdlib.h'
 checkfunc d_mktime 'mktime' 'NULL' 'time.h'
-checkfunc d_mktime64 'mktime64'
+checkfunc d_mktime64 'mktime64' 'NULL' 'time.h'
 checkfunc d_mmap 'mmap' 'NULL,0,0,0,0,0' 'sys/mman.h'
 checkfunc d_mprotect 'mprotect' 'NULL,0,0' 'sys/mman.h'
 checkfunc d_msgctl 'msgctl' '0,0,NULL' 'sys/msg.h'
@@ -193,7 +206,7 @@ checkfunc d_prctl 'prctl' '0,0,0,0,0' 'sys/prctl.h'
 checkfunc d_pthread_atfork 'pthread_atfork' 'NULL,NULL,NULL' 'pthread.h'
 checkfunc d_pthread_attr_setscope 'pthread_attr_setscope' 'NULL,0' 'pthread.h'
 checkfunc d_pthread_yield 'pthread_yield' '' 'pthread.h'
-checkfunc d_querylocale 'querylocale'
+checkfunc d_querylocale 'querylocale' '0,NULL' 'locale.h'
 checkfunc d_qgcvt 'qgcvt' '1.0,1,NULL'
 checkfunc d_rand 'rand' '' 'stdlib.h'
 checkfunc d_random 'random' '' 'stdlib.h'
@@ -265,11 +278,11 @@ checkfunc d_strftime 'strftime' "NULL,0,NULL,NULL" 'time.h'
 checkfunc d_strlcat 'strlcat' 'NULL,NULL,0' 'string.h'
 checkfunc d_strlcpy 'strlcpy' 'NULL,NULL,0' 'string.h'
 checkfunc d_strnlen 'strnlen' '"",0' 'string.h'
-checkfunc d_strtod 'strtod' 'NULL,NULL'
-checkfunc d_strtod_l 'strtod_l'
-checkfunc d_strtol 'strtol' 'NULL,NULL,0'
-checkfunc d_strtold 'strtold' 'NULL,NULL'
-checkfunc d_strtold_l 'strtold_l'
+checkfunc d_strtod 'strtod' 'NULL,NULL' 'stdlib.h'
+checkfunc d_strtod_l 'strtod_l' 'NULL,NULL,NULL' 'stdlib.h'
+checkfunc d_strtol 'strtol' 'NULL,NULL,0' 'stdlib.h'
+checkfunc d_strtold 'strtold' 'NULL,NULL' 'stdlib.h'
+checkfunc d_strtold_l 'strtold_l' 'NULL,NULL,NULL' 'stdlib.h'
 checkfunc d_strtoll 'strtoll' 'NULL,NULL,0'
 checkfunc d_strtoq 'strtoq' 'NULL,NULL,0'
 checkfunc d_strtoul 'strtoul' 'NULL,NULL,0'
@@ -280,7 +293,7 @@ checkfunc d_strxfrm_l 'strxfrm_l' 'NULL,NULL,0,NULL' 'string.h'
 checkfunc d_symlink 'symlink' 'NULL,NULL' 'unistd.h'
 checkfunc d_syscall 'syscall' '0,NULL' 'sys/syscall.h unistd.h'
 checkfunc d_sysconf 'sysconf' '0' 'unistd.h'
-checkfunc d_system 'system' 'NULL'
+checkfunc d_system 'system' 'NULL' 'stdlib.h'
 checkfunc d_tcgetpgrp 'tcgetpgrp' '0' 'unistd.h'
 checkfunc d_tcsetpgrp 'tcsetpgrp' '0,0' 'unistd.h'
 checkfunc d_telldir 'telldir' 'NULL' 'dirent.h'
